summaryrefslogtreecommitdiffstats
path: root/gst/rtp/gstrtpmp4vpay.c
diff options
context:
space:
mode:
authorThomas Vander Stichele <thomas@apestaart.org>2005-12-01 14:39:30 +0000
committerThomas Vander Stichele <thomas@apestaart.org>2005-12-01 14:39:30 +0000
commitfe967d4fe869959df133e4d1b5d304ed60a2fd41 (patch)
treec99f63c8b69ee293c0638c7df6cc7abc26340622 /gst/rtp/gstrtpmp4vpay.c
parent7a4f8655ce2679dc535d6698630dbc087dc1ce87 (diff)
gst/rtp/: parsers are depayers
Original commit message from CVS: * gst/rtp/Makefile.am: * gst/rtp/gstrtpL16depay.c: * gst/rtp/gstrtpL16depay.h: * gst/rtp/gstrtpL16parse.c: * gst/rtp/gstrtpL16parse.h: * gst/rtp/gstrtpgsmdepay.c: * gst/rtp/gstrtpgsmdepay.h: * gst/rtp/gstrtpgsmparse.c: * gst/rtp/gstrtpgsmparse.h: parsers are depayers
Diffstat (limited to 'gst/rtp/gstrtpmp4vpay.c')
-rw-r--r--gst/rtp/gstrtpmp4vpay.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gst/rtp/gstrtpmp4vpay.c b/gst/rtp/gstrtpmp4vpay.c
index cccfa724..9463f45e 100644
--- a/gst/rtp/gstrtpmp4vpay.c
+++ b/gst/rtp/gstrtpmp4vpay.c
@@ -263,7 +263,7 @@ gst_rtp_mp4v_pay_flush (GstRtpMP4VPay * rtpmp4vpay)
#define VOP_STARTCODE 0x000001B6
static gboolean
-gst_rtp_mp4v_pay_parse_data (GstRtpMP4VPay * enc, guint8 * data, guint size,
+gst_rtp_mp4v_pay_depay_data (GstRtpMP4VPay * enc, guint8 * data, guint size,
gint * strip)
{
guint32 code;
@@ -363,9 +363,9 @@ gst_rtp_mp4v_pay_handle_buffer (GstBaseRTPPayload * basepayload,
rtpmp4vpay->duration = 0;
}
/* parse incomming data and see if we need to start a new RTP
* packet */
- flush = gst_rtp_mp4v_pay_parse_data (rtpmp4vpay, data, size, &strip);
+ flush = gst_rtp_mp4v_pay_depay_data (rtpmp4vpay, data, size, &strip);
if (strip) {
/* strip off config if requested */
if (!rtpmp4vpay->send_config) {
@@ -363,9 +363,9 @@ gst_rtp_mp4v_pay_handle_buffer (GstBaseRTPPayload * basepayload,
rtpmp4vpay->duration = 0;
}
- /* parse incomming data and see if we need to start a new RTP
+ /* depay incomming data and see if we need to start a new RTP
* packet */